@@ -1,26 +1,13 @@
 /*
-    Copyright (C) 2013  David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2013 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "metacontact_p.h"
 #include "global.h"
 #include <QSharedData>
-#include <QDebug>
-#include <QSet>
+#include "kpeople_debug.h"
 
 namespace KPeople
 {
@@ -44,11 +31,11 @@ public:
         : m_contacts(contacts)
     {}
 
-    QVariant customProperty(const QString &key) const Q_DECL_OVERRIDE
+    QVariant customProperty(const QString &key) const override
     {
         if (key.startsWith(QLatin1String("all-"))) {
             QVariantList ret;
-            Q_FOREACH (const AbstractContact::Ptr &contact, m_contacts) {
+            for (const AbstractContact::Ptr &contact : qAsConst(m_contacts)) {
                 QVariant val = contact->customProperty(key);
                 Q_ASSERT(val.canConvert<QVariantList>() || val.isNull());
 
@@ -58,7 +45,7 @@ public:
             }
             return ret;
         } else {
-            Q_FOREACH (const AbstractContact::Ptr &contact, m_contacts) {
+            for (const AbstractContact::Ptr &contact : qAsConst(m_contacts)) {
                 QVariant val = contact->customProperty(key);
                 if (val.isValid()) {
                     return val;
@@ -162,7 +149,7 @@ int MetaContact::insertContact(const QString &contactUri, const AbstractContact:
     if (index >= 0) {
         reload();
     } else {
-        qWarning() << "Inserting an already-present contact" << contactUri;
+        qCWarning(KPEOPLE_LOG) << "Inserting an already-present contact" << contactUri;
     }
     return index;
 }
@@ -186,7 +173,7 @@ int MetaContact::updateContact(const QString &contactUri, const AbstractContact:
     const int index = d->contactUris.indexOf(contactUri);
     Q_ASSERT(index < 0 || d->contacts[index] == contact);
     if (index < 0) {
-        qWarning() << "contact not part of the metacontact";
+        qCWarning(KPEOPLE_LOG) << "contact not part of the metacontact";
     }
     return index;
 }
