@@ -1,20 +1,8 @@
 /*
     KPeople - Duplicates
-    Copyright (C) 2013  Franck Arrecot <franck.arrecot@gmail.com>
+    SPDX-FileCopyrightText: 2013 Franck Arrecot <franck.arrecot@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "mergedelegate.h"
@@ -23,15 +11,13 @@
 #include <match_p.h>
 
 #include <QPainter>
-#include <QPixmap>
 #include <QStyleOptionViewItem>
 #include <QAbstractItemView>
 #include <QModelIndex>
-#include <QApplication>
 #include <QLabel>
 #include <QCheckBox>
 #include <QItemSelection>
-#include <QDebug>
+#include "kpeople_widgets_debug.h"
 #include <QIcon>
 #include <KLocalizedString>
 
@@ -90,9 +76,10 @@ void MergeDelegate::onSelectedContactsChanged(const QItemSelection &now , const
 QWidget *MergeDelegate::buildMultipleLineLabel(const QModelIndex &idx)
 {
     QString contents;
-    int rows = idx.model()->rowCount(idx);
+    const QAbstractItemModel *model = idx.model();
+    const int rows = model->rowCount(idx);
     for (int i = 0 ; i < rows; ++i) {
-        QModelIndex child = idx.child(i, 0);
+        const QModelIndex child = model->index(i, 0, idx);
         Match m = child.data(MergeDialog::MergeReasonRole).value<Match>();
 
         QString name = m.indexB.data(Qt::DisplayRole).toString();
@@ -108,14 +95,15 @@ QWidget *MergeDelegate::buildMultipleLineLabel(const QModelIndex &idx)
 void MergeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optionOld, const QModelIndex &index) const
 {
     QStyleOptionViewItem option(optionOld);
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     KExtendableItemDelegate::paint(painter, option, index);
 
     const int separation = 5;
 
-    int facesRows = qMin(index.model()->rowCount(index), MAX_MATCHING_CONTACTS_ICON);
+    const QAbstractItemModel *model = index.model();
+    int facesRows = qMin(model->rowCount(index), MAX_MATCHING_CONTACTS_ICON);
     for (int i = 0; i < facesRows; i++) { // Children Icon Displaying Loop
-        const QModelIndex child = index.child(i, 0);
+        const QModelIndex child = model->index(i, 0, index);
 
         QVariant decoration = child.data(Qt::DecorationRole);
         Q_ASSERT(decoration.type() == (QVariant::Icon));
@@ -126,7 +114,7 @@ void MergeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optionO
     }
     // draw a vertical line to separate the original person and the merging contacts
     int midWidth = option.rect.width() / 2;
-    painter->setPen(opt.palette.color(QPalette::Background));
+    painter->setPen(opt.palette.color(QPalette::Window));
     painter->drawLine(option.rect.left() + midWidth - SIZE_STANDARD_PIXMAP, option.rect.bottom() - 5,
                       option.rect.left() + midWidth - SIZE_STANDARD_PIXMAP, option.rect.top() + 5);
 }
